@@ -90,12 +90,14 @@ class RedisCustomer(object):
     def _start_consuming_message_thread(self):
         while True:
             try:
+                get_queue_begin_time = time.time()
                 message = self._redis_quenen.get()
+                get_message_cost = time.time() - get_queue_begin_time
                 if message:
                     if isinstance(message, list):
                         for msg in message:
                             if self.qps != 0:
-                                time.sleep((1 / self.qps) * self.process_num)
+                                time.sleep((1 / self.qps) * self.process_num - get_message_cost)
                             if self.is_support_mutil_param and '{' in message and '}' in message:
                                 message = json.loads(msg)
                                 if type(message) != dict:
@@ -103,7 +105,7 @@ class RedisCustomer(object):
                             self._threadpool.submit(self._consuming_exception_retry, msg)
                     else:
                         if self.qps != 0:
-                            time.sleep((1 / self.qps) * self.process_num)
+                            time.sleep((1 / self.qps) * self.process_num - get_message_cost)
                         if self.is_support_mutil_param and '{' in message and '}' in message:
                             message = json.loads(message)
                             if type(message) != dict:
@@ -304,7 +306,7 @@ if __name__ == '__main__':
     # 批量提交任务 queue_name提交任务队列名称 max_push_size每次批量提交记录数(默认值50)
     RedisPublish(queue_name='test3', max_push_size=100).publish_redispy_list(result)
     # 消费者类型 string 支持('thread','gevent') 默认thread
-    RedisCustomer(queue_name='test3', consuming_function=print_msg_dict(), customer_type='gevent',
+    RedisCustomer(queue_name='test3', consuming_function=print_msg_dict, customer_type='gevent',
                   qps=50).start_consuming_message()
 
     # #### 4.切换任务队列中间件为sqlite(默认为redis)
